@@ -112,7 +112,8 @@ PARAMS = {
             'show': True,
             'notifications' : True,
             'trackpad-lock' : True,
-            'power-profile' : True
+            'power-profile' : True,
+            'ac-notifications' : True
             }
 
 POWER_PROFILE_POWER_SAVER = "power-saver"
@@ -143,8 +144,9 @@ POWER_NAME_TO_EVENT = {
     TUNED_PROFILE[POWER_PROFILE_PERFORMANCE] : SLB_EVENT_UPOWER_PERFORMANCE
 }
 
-OPT_TRACKPAD_LOCK = "trackpad-lock"
-OPT_POWER_PROFILE = "power-profile"
+OPT_TRACKPAD_LOCK    = "trackpad-lock"
+OPT_POWER_PROFILE    = "power-profile"
+OPT_AC_NOTIFICATIONS = "ac-notifications"
 
 CMD_LOAD_SETTINGS = "cmd-load"
 
@@ -211,14 +213,13 @@ ICONDIR = os.path.join(APPDIR, 'icons')
 FILE_AUTO_START_ORIG = os.path.join(APPDIR,
                                     'slimbook-client-autostart.desktop')
 
-ICONDIR = os.path.join(APPDIR, 'icons')
-ICON = os.path.join(ICONDIR, 'slimbook_be1ofus_light.svg')
+ICON = 'slimbook-be1ofus-light'
 
 STATUS_ICON = {}
-STATUS_ICON['light'] = (os.path.join(ICONDIR, 'slimbook-status-active-light.svg'))
-STATUS_ICON['light-attention'] = (os.path.join(ICONDIR, 'slimbook-status-attention-light.svg'))
-STATUS_ICON['dark'] = (os.path.join(ICONDIR, 'slimbook-status-active-dark.svg'))
-STATUS_ICON['dark-attention'] = (os.path.join(ICONDIR, 'slimbook-status-attention-dark.svg'))
+STATUS_ICON['light'] = 'slimbook-status-active-light'
+STATUS_ICON['light-attention'] = 'slimbook-status-attention-light'
+STATUS_ICON['dark'] = 'slimbook-status-active-dark'
+STATUS_ICON['dark-attention'] = 'slimbook-status-attention-dark'
 
 INFO_UPTIME = _("Uptime")
 INFO_MEM = _("Memory Free/Total")
